@@ -70,8 +70,8 @@ class TestSelectingHandler(object):
         )
 
         url = 'http://localhost:8080/v2.0/test4/11/test5/12'
-        elements = filter(
-            None, six.moves.urllib_parse.urlparse(url).path.split('/'))[1:]
+        elements = list(filter(
+            None, six.moves.urllib_parse.urlparse(url).path.split('/')))[1:]
         handler, params = SelectingHandler.get_response_handler(
             response_handlers, 'TEST3', elements
         )
